%{?mingw_package_header}

%global pkgname libzip

Name:           mingw-%{pkgname}
Version:        1.10.1
Release:        %mkrel 1
Summary:        C library for reading, creating, and modifying zip archives

Group:          Development/Other
License:        BSD
BuildArch:      noarch
URL:            https://www.nih.at/libzip/index.html
Source0:        https://www.nih.at/libzip/%{pkgname}-%{version}.tar.xz
# CMake fixes:
# - Add soversion suffix, as was the case previously with autotools build
# - Workaround CMAKE_DL_LIBS not defined on MINGW (https://gitlab.kitware.com/cmake/cmake/issues/17600)
# - Fix nonrandomopentest non linked to nonrandomopen
Patch0:         libzip_cmake.patch

BuildRequires:  cmake

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-bzip2
BuildRequires:  mingw32-dlfcn
BuildRequires:  mingw32-zlib >= 1.1.2

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-bzip2
BuildRequires:  mingw64-dlfcn
BuildRequires:  mingw64-zlib >= 1.1.2

%description
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from 
other zip archives. Changes made without closing the archive can be reverted. 
The API is documented by man pages.


%package -n mingw32-%{pkgname}
Summary:        C library for reading, creating, and modifying zip archives

%description -n mingw32-%{pkgname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.


%package -n mingw64-%{pkgname}
Summary:        C library for reading, creating, and modifying zip archives

%description -n mingw64-%{pkgname}
libzip is a C library for reading, creating, and modifying zip archives. Files
can be added from data buffers, files, or compressed data copied directly from
other zip archives. Changes made without closing the archive can be reverted.
The API is documented by man pages.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{pkgname}-%{version}

# fix build
sed -i 's|Windows.h|windows.h|' lib/zip_crypto_win.c


%build
%mingw_cmake
%mingw_make_build


%install
%mingw_make_install

# Remove unused files
rm -r %{buildroot}%{mingw32_datadir}
rm -r %{buildroot}%{mingw64_datadir}


%files -n mingw32-%{pkgname}
%license LICENSE
%{mingw32_bindir}/zipcmp.exe
%{mingw32_bindir}/zipmerge.exe
%{mingw32_bindir}/ziptool.exe
%{mingw32_bindir}/libzip-5.dll
%{mingw32_libdir}/libzip.dll.a
%{mingw32_libdir}/pkgconfig/libzip.pc
%{mingw32_libdir}/cmake/libzip/
%{mingw32_includedir}/zip.h
%{mingw32_includedir}/zipconf.h

%files -n mingw64-%{pkgname}
%license LICENSE
%{mingw64_bindir}/zipcmp.exe
%{mingw64_bindir}/zipmerge.exe
%{mingw64_bindir}/ziptool.exe
%{mingw64_bindir}/libzip-5.dll
%{mingw64_libdir}/libzip.dll.a
%{mingw64_libdir}/pkgconfig/libzip.pc
%{mingw64_libdir}/cmake/libzip/
%{mingw64_includedir}/zip.h
%{mingw64_includedir}/zipconf.h




%changelog
* Fri Oct 13 2023 daviddavid <daviddavid> 1.10.1-1.mga10
+ Revision: 1995892
- new version: 1.10.1

* Mon Nov 21 2022 daviddavid <daviddavid> 1.9.2-1.mga9
+ Revision: 1909770
- new version 1.9.2

* Thu Mar 24 2022 umeabot <umeabot> 1.7.3-3.mga9
+ Revision: 1825439
- Mageia 9 Mass Rebuild

* Sat Sep 26 2020 tv <tv> 1.7.3-2.mga8
+ Revision: 1630212
- rebuild for new mingw stack

* Thu Jul 16 2020 daviddavid <daviddavid> 1.7.3-1.mga8
+ Revision: 1606604
- new version: 1.7.3

* Sat Jun 20 2020 daviddavid <daviddavid> 1.7.1-1.mga8
+ Revision: 1597906
- new version: 1.7.1

* Thu Feb 20 2020 umeabot <umeabot> 1.6.1-2.mga8
+ Revision: 1546511
- Mageia 8 Mass Rebuild

* Mon Feb 03 2020 daviddavid <daviddavid> 1.6.1-1.mga8
+ Revision: 1486646
- new version: 1.6.1

* Fri Jan 24 2020 daviddavid <daviddavid> 1.6.0-1.mga8
+ Revision: 1482711
- new version: 1.6.0

* Wed Mar 13 2019 daviddavid <daviddavid> 1.5.2-1.mga7
+ Revision: 1375253
- new version: 1.5.2

* Thu Sep 20 2018 umeabot <umeabot> 1.5.1-2.mga7
+ Revision: 1279923
- Mageia 7 Mass Rebuild

* Mon Aug 06 2018 daviddavid <daviddavid> 1.5.1-1.mga7
+ Revision: 1248281
- new version: 1.5.1

* Wed May 11 2016 tv <tv> 1.1.2-2.mga6
+ Revision: 1012806
+ rebuild (emptylog)

* Wed May 11 2016 tv <tv> 1.1.2-1.mga6
+ Revision: 1012744
- new release

* Mon Feb 08 2016 umeabot <umeabot> 0.11.1-6.mga6
+ Revision: 947938
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.11.1-5.mga5
+ Revision: 745053
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.11.1-4.mga5
+ Revision: 682497
- Mageia 5 Mass Rebuild

* Mon Oct 28 2013 neoclust <neoclust> 0.11.1-3.mga4
+ Revision: 547565
- imported package mingw-libzip


* Tue Sep 17 2013 Sandro Mani <manisandro@gmail.com> - 0.11.1-3
- Link zipconf.h to include dir (fix rhbz#1008128)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 16 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.11.1-1
- Update to 0.11.1
- Use a more verbose filelist

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec 03 2012 Alexandru Gagniuc <mr.nuke.me@gmail.com> - 0.9-8
- Added target for mingw64

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 07 2012 Kalev Lember <kalevlember@gmail.com> - 0.9-6
- Renamed the source package to mingw-libzip (#800932)
- Modernize the spec file
- Use mingw macros without leading underscore

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.9-5
- Rebuild against the mingw-w64 toolchain

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 22 2009 David Ludlow <dave@adsllc.com> - 0.9-2
- Prevent owning a directory that is not mine to own

* Tue Dec 22 2009 David Ludlow <dave@adsllc.com> - 0.9-1
- Initial creation of mingw32 package
